import 'dart:developer';

import 'package:dio/dio.dart';
import 'package:pmu_project/data/dtos/characters_dto.dart';
import 'package:pmu_project/data/mappers/characters_mapper.dart';
import 'package:pmu_project/data/repositories/api_interface.dart';
import 'package:pmu_project/domain/models/card_data.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

class GravityFallsRepository extends ApiInterface {
  static final Dio _dio = Dio(BaseOptions(
      connectTimeout: const Duration(seconds: 20),
      receiveTimeout: const Duration(seconds: 20)))
    ..interceptors.add(
        PrettyDioLogger(request: true, requestHeader: true, requestBody: true));

  static const String _baseUrl = "http://10.0.2.2:3000";

  @override
  Future<List<CardData>?> loadData(String? q) async {
    try {
      final Response<dynamic> response = await _dio.get<Map<dynamic, dynamic>>(
        _baseUrl,
        queryParameters: {'name': q},
      );

      final GCharactersDataDto dto =
      GCharactersDataDto.fromJson(response.data as Map<String, dynamic>);

      final List<CardData>? data = dto.results?.map((e) => e.toDomain()).toList();

      return data;
    } on DioException catch (e) {
      log("DioException: $e");
      return null;
    } catch (e) {
      log('Unknown error: $e');
      return null;
    }
  }
}